Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1480)

Unified Diff: content/public/browser/host_zoom_map.h

Issue 2630583002: Add setting to isolate zoom changes by default. (Closed)
Patch Set: ... and tell closure_compiler. Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/browser/host_zoom_map_impl.h ('k') | tools/metrics/histograms/histograms.xml » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/public/browser/host_zoom_map.h
diff --git a/content/public/browser/host_zoom_map.h b/content/public/browser/host_zoom_map.h
index 61514db8d37da71b699d27d4e43604995fba30fe..27c232ff9158ef27bde9d3b5973bd60eb370b225 100644
--- a/content/public/browser/host_zoom_map.h
+++ b/content/public/browser/host_zoom_map.h
@@ -148,15 +148,23 @@ class HostZoomMap {
virtual bool UsesTemporaryZoomLevel(int render_process_id,
int render_view_id) const = 0;
- // Sets the temporary zoom level that's only valid for the lifetime of this
- // WebContents.
+ // Returns the temporary zoom level that's only valid for the lifetime of
+ // the given view (i.e. isn't saved and doesn't affect other WebContentses)
+ // if it exists, the default zoom level otherwise.
+ //
+ // This may be called on any thread.
+ virtual double GetTemporaryZoomLevel(int render_process_id,
+ int render_view_id) const = 0;
+
+ // Sets the temporary zoom level that's only valid for the lifetime of the
+ // given view.
//
// This should only be called on the UI thread.
virtual void SetTemporaryZoomLevel(int render_process_id,
int render_view_id,
double level) = 0;
// Clears the temporary zoom level stored for this WebContents.
//
// This should only be called on the UI thread.
virtual void ClearTemporaryZoomLevel(int render_process_id,
@@ -148,15 +148,23 @@ class HostZoomMap {
int render_view_id,
double level) = 0;
- // Clears the temporary zoom level stored for this WebContents.
+ // Clears the temporary zoom level stored for the given view.
//
// This should only be called on the UI thread.
« no previous file with comments | « content/browser/host_zoom_map_impl.h ('k') | tools/metrics/histograms/histograms.xml » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698